@@ -1,29 +1,25 @@
-#  Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-#  SPDX-License-Identifier: Apache-2.0
-
 from unittest import skip
-
 from servicecatalog_puppet.workflow import tasks_unit_tests_helper
 
 
 class ProvisionProductTaskTest(tasks_unit_tests_helper.PuppetTaskUnitTest):
     manifest_file_path = "manifest_file_path"
     launch_name = "launch_name"
+    region = "region"
+    account_id = "account_id"
     portfolio = "portfolio"
     product = "product"
     version = "version"
-    region = "region"
-    account_id = "account_id"
-    puppet_account_id = "puppet_account_id"
+    portfolio_get_all_products_and_their_versions_ref = (
+        "portfolio_get_all_products_and_their_versions_ref"
+    )
+    describe_provisioning_params_ref = "describe_provisioning_params_ref"
     ssm_param_inputs = []
     launch_parameters = {}
     manifest_parameters = {}
     account_parameters = {}
-    retry_count = 1
-    worker_timeout = 3
     ssm_param_outputs = []
-
-    requested_priority = 1
+    tags = []
     execution = "execution"
 
     def setUp(self) -> None:
@@ -32,23 +28,23 @@ class ProvisionProductTaskTest(tasks_unit_tests_helper.PuppetTaskUnitTest):
         self.module = provision_product_task
 
         self.sut = self.module.ProvisionProductTask(
+            **self.get_common_args(),
             manifest_file_path=self.manifest_file_path,
             launch_name=self.launch_name,
+            region=self.region,
+            account_id=self.account_id,
             portfolio=self.portfolio,
             product=self.product,
             version=self.version,
-            region=self.region,
-            account_id=self.account_id,
-            puppet_account_id=self.puppet_account_id,
+            portfolio_get_all_products_and_their_versions_ref=self.portfolio_get_all_products_and_their_versions_ref,
+            describe_provisioning_params_ref=self.describe_provisioning_params_ref,
             ssm_param_inputs=self.ssm_param_inputs,
             launch_parameters=self.launch_parameters,
             manifest_parameters=self.manifest_parameters,
             account_parameters=self.account_parameters,
-            retry_count=self.retry_count,
-            worker_timeout=self.worker_timeout,
             ssm_param_outputs=self.ssm_param_outputs,
-            requested_priority=self.requested_priority,
             execution=self.execution,
+            tags=self.tags,
         )
 
         self.wire_up_mocks()
@@ -67,26 +63,26 @@ class ProvisionProductTaskTest(tasks_unit_tests_helper.PuppetTaskUnitTest):
         actual_result = self.sut.params_for_results_display()
 
         # verify
-        self.assertDictEqual(expected_result, actual_result)
+        self.assertEqual(expected_result, actual_result)
 
     def test_api_calls_used(self):
         # setup
         expected_result = [
-            f"servicecatalog.scan_provisioned_products_single_page_{self.account_id}_{self.region}",
-            f"servicecatalog.describe_provisioned_product_{self.account_id}_{self.region}",
-            f"servicecatalog.terminate_provisioned_product_{self.account_id}_{self.region}",
-            f"servicecatalog.describe_record_{self.account_id}_{self.region}",
-            f"cloudformation.get_template_summary_{self.account_id}_{self.region}",
-            f"cloudformation.describe_stacks_{self.account_id}_{self.region}",
-            f"servicecatalog.list_provisioned_product_plans_single_page_{self.account_id}_{self.region}",
-            f"servicecatalog.delete_provisioned_product_plan_{self.account_id}_{self.region}",
-            f"servicecatalog.create_provisioned_product_plan_{self.account_id}_{self.region}",
-            f"servicecatalog.describe_provisioned_product_plan_{self.account_id}_{self.region}",
-            f"servicecatalog.execute_provisioned_product_plan_{self.account_id}_{self.region}",
-            f"servicecatalog.describe_provisioned_product_{self.account_id}_{self.region}",
-            f"servicecatalog.update_provisioned_product_{self.account_id}_{self.region}",
-            f"servicecatalog.provision_product_{self.account_id}_{self.region}",
-            f"servicecatalog.list_launch_paths_{self.account_id}_{self.region}",
+            "servicecatalog.scan_provisioned_products_single_page_account_id_region",
+            "servicecatalog.describe_provisioned_product_account_id_region",
+            "servicecatalog.terminate_provisioned_product_account_id_region",
+            "servicecatalog.describe_record_account_id_region",
+            "cloudformation.get_template_summary_account_id_region",
+            "cloudformation.describe_stacks_account_id_region",
+            "servicecatalog.list_provisioned_product_plans_single_page_account_id_region",
+            "servicecatalog.delete_provisioned_product_plan_account_id_region",
+            "servicecatalog.create_provisioned_product_plan_account_id_region",
+            "servicecatalog.describe_provisioned_product_plan_account_id_region",
+            "servicecatalog.execute_provisioned_product_plan_account_id_region",
+            "servicecatalog.describe_provisioned_product_account_id_region",
+            "servicecatalog.update_provisioned_product_account_id_region",
+            "servicecatalog.provision_product_account_id_region",
+            "servicecatalog.list_launch_paths_account_id_region",
         ]
 
         # exercise
