@@ -1,16 +1,10 @@
-#  Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-#  SPDX-License-Identifier: Apache-2.0
-
 from unittest import skip
-
 from servicecatalog_puppet.workflow import tasks_unit_tests_helper
 
 
 class ProvisioningArtifactParametersTaskTest(
     tasks_unit_tests_helper.PuppetTaskUnitTest
 ):
-    manifest_file_path = "manifest_file_path"
-    puppet_account_id = "puppet_account_id"
     portfolio = "portfolio"
     product = "product"
     version = "version"
@@ -24,8 +18,7 @@ class ProvisioningArtifactParametersTaskTest(
         self.module = provisioning_artifact_parameters_task
 
         self.sut = self.module.ProvisioningArtifactParametersTask(
-            manifest_file_path=self.manifest_file_path,
-            puppet_account_id=self.puppet_account_id,
+            **self.get_common_args(),
             portfolio=self.portfolio,
             product=self.product,
             version=self.version,
@@ -39,9 +32,9 @@ class ProvisioningArtifactParametersTaskTest(
         expected_result = {
             "puppet_account_id": self.puppet_account_id,
             "portfolio": self.portfolio,
+            "region": self.region,
             "product": self.product,
             "version": self.version,
-            "region": self.region,
             "cache_invalidator": self.cache_invalidator,
         }
 
@@ -53,7 +46,9 @@ class ProvisioningArtifactParametersTaskTest(
 
     def test_api_calls_used(self):
         # setup
-        expected_result = []
+        expected_result = [
+            f"servicecatalog.describe_provisioning_parameters_{self.puppet_account_id}_{self.region}",
+        ]
 
         # exercise
         actual_result = self.sut.api_calls_used()
